BeamBackend

Struct BeamBackend 

pub struct BeamBackend {
    pub module: BeamModule,
    /* private fields */
}
BEAM VM code generation backend.

Converts LCNF IR into Core Erlang source representation suitable for further compilation by the Erlang compiler (erlc).

Fields

module: BeamModule

The module being generated

Implementations

Source

impl BeamBackend

pub fn new(module_name: impl Into<String>) -> Self

Create a new BEAM backend for the given module name.

pub fn emit_literal(&self, lit: &LcnfLit) -> BeamExpr

Convert an LCNF literal to a BeamExpr.

pub fn emit_arg(&mut self, arg: &LcnfArg) -> BeamExpr

Convert an LCNF argument to a BeamExpr.

pub fn emit_let_value(&mut self, val: &LcnfLetValue) -> BeamExpr

Convert an LCNF let-value to a BeamExpr.

pub fn emit_expr(&mut self, expr: &LcnfExpr) -> BeamExpr

Emit a Core Erlang expression from an LCNF expression.

pub fn emit_fun_decl(&mut self, decl: &LcnfFunDecl) -> BeamFunction

Emit a complete LCNF function declaration as a BeamFunction.

pub fn emit_core_erlang(&mut self) -> String

Emit a full Core Erlang source file for the module.

pub fn emit_asm(&self) -> String

Emit BEAM assembly (human-readable instruction dump).