pub struct BeamLinker { /* private fields */ }Expand description
Links multiple BEAM modules into a combined module by merging functions.
Used for compiling multiple source files into a single Erlang module (e.g., when inlining helper libraries).
Implementations
Sourceimpl BeamLinker
impl BeamLinker
Sourcepub fn new(target: impl Into<String>) -> Self
pub fn new(target: impl Into<String>) -> Self
Create a new linker targeting the given module name.
Sourcepub fn add_module(&mut self, module: BeamModule)
pub fn add_module(&mut self, module: BeamModule)
Add a module to be linked.
Sourcepub fn rename(
&mut self,
src_module: impl Into<String>,
src_name: impl Into<String>,
new_name: impl Into<String>,
)
pub fn rename( &mut self, src_module: impl Into<String>, src_name: impl Into<String>, new_name: impl Into<String>, )
Rename a function during linking to avoid name collisions.
Sourcepub fn link(self) -> BeamModule
pub fn link(self) -> BeamModule
Perform the link and produce a merged BeamModule.