pub enum EscapeInfo {
NoEscape,
LocalEscape,
GlobalEscape,
}Expand description
The escape status of a closure or variable.
Variants
NoEscape
The value does not escape its defining scope. It can be stack-allocated.
LocalEscape
The value escapes within the current function (e.g. stored in a local data structure) but does not escape the function itself.
GlobalEscape
The value escapes the function (e.g. returned, stored in a global, or passed to an unknown function). Must be heap-allocated.
Implementations
Sourceimpl EscapeInfo
impl EscapeInfo
Sourcepub fn merge(self, other: EscapeInfo) -> EscapeInfo
pub fn merge(self, other: EscapeInfo) -> EscapeInfo
Merge two escape infos, taking the more conservative (higher) one.
Sourcepub fn requires_heap(self) -> bool
pub fn requires_heap(self) -> bool
Whether heap allocation is required.