CraneliftFunction

Struct CraneliftFunction 

pub struct CraneliftFunction {
    pub name: String,
    pub sig: Signature,
    pub stack_slots: Vec<(u32, u32)>,
    pub global_values: Vec<(u32, String)>,
    pub sig_refs: Vec<(u32, Signature)>,
    pub func_refs: Vec<(u32, String, u32)>,
    pub blocks: Vec<CraneliftBlock>,
    /* private fields */
}
A Cranelift function definition.

Fields

name: String

Function name

sig: Signature

Function signature

stack_slots: Vec<(u32, u32)>

Stack slots: (slot_id, size_bytes)

global_values: Vec<(u32, String)>

Global values referenced: (gv_id, name)

sig_refs: Vec<(u32, Signature)>

Signature references for indirect calls: (sig_id, signature)

func_refs: Vec<(u32, String, u32)>

Function references for direct calls: (fn_ref_id, name, sig_id)

blocks: Vec<CraneliftBlock>

Basic blocks (first block is the entry block)

Implementations

Source

impl CraneliftFunction

pub fn new(name: impl Into<String>, sig: Signature) -> Self

Create a new function.

pub fn fresh_value(&mut self, ty: CraneliftType) -> CraneliftValue

Allocate a fresh SSA value with the given type.

pub fn new_block(&mut self) -> u32

Create a new block and return its block reference.

pub fn new_block_with_params(&mut self, param_types: &[CraneliftType]) -> u32

Create a new block with parameters.

pub fn block_mut(&mut self, id: u32) -> Option<&mut CraneliftBlock>

Get a mutable reference to a block by id.

pub fn add_stack_slot(&mut self, size_bytes: u32) -> u32

Add a stack slot.

pub fn emit(&self) -> String

Emit this function as textual IR.