pub fn float_with_measure(value: f64, measure: &str) -> FSharpExprExpand description
Build a float with a unit of measure annotation: 42.0<kg>.
pub fn float_with_measure(value: f64, measure: &str) -> FSharpExprBuild a float with a unit of measure annotation: 42.0<kg>.