Module functions

Module functions 

Functions for the LCNF IR serialization module.

Constants

CURRENT_VERSION
The version number embedded into every freshly serialized snapshot.

Functions

deserialize_ir
Deserialize the text data that was produced in format.
diff_modules
Compute the diff between two module snapshots.
ir_from_json
Deserialize a JSON-encoded IR snapshot produced by ir_to_json.
ir_from_text
Deserialize the text format produced by ir_to_text.
ir_to_json
Serialize module to a JSON string (always pretty-printed).
ir_to_text
Serialize module to a human-readable text format.
merge_modules
Merge two modules into one. Returns an error if any declaration name appears in both a and b.
serialize_decl
Serialize a single declaration according to cfg.
serialize_ir
Serialize module to a string using the format specified in cfg.