JuliaBackend

Struct JuliaBackend 

pub struct JuliaBackend { /* private fields */ }
Julia code generation backend.

Implementations

Source

impl JuliaBackend

pub fn new() -> Self

Create a new Julia backend.

pub fn register_method(&mut self, func: JuliaFunction)

Register a method into the dispatch table for its function name.

pub fn emit_expr(&self, expr: &JuliaExpr) -> String

Emit a Julia expression to a String.

pub fn emit_type(&self, ty: &JuliaType) -> String

Emit a Julia type to a String.

pub fn emit_function(&mut self, func: &JuliaFunction)

Emit a Julia function definition to the output buffer.

pub fn emit_struct(&mut self, s: &JuliaStruct)

Emit a Julia struct definition to the output buffer.

pub fn emit_module(&mut self, m: &JuliaModule)

Emit a Julia module definition to the output buffer.

pub fn emit_stmt(&mut self, stmt: &JuliaStmt)

Emit a Julia statement to the output buffer.

pub fn emit_dispatch_tables(&mut self)

Emit all registered dispatch table methods (for multiple dispatch).

pub fn take_output(&mut self) -> String

Take the output buffer and return it.

pub fn output(&self) -> &str

Get a reference to the output buffer.