LcnfLetValue

Enum LcnfLetValue 

pub enum LcnfLetValue {
    App(LcnfArg, Vec<LcnfArg>),
    Proj(String, u32, LcnfVarId),
    Ctor(String, u32, Vec<LcnfArg>),
    Lit(LcnfLit),
    Erased,
    FVar(LcnfVarId),
    Reset(LcnfVarId),
    Reuse(LcnfVarId, String, u32, Vec<LcnfArg>),
}
A let-bound value in LCNF.

In ANF, every complex operation is let-bound so that arguments to subsequent operations are always atomic.

Variants



App(LcnfArg, Vec<LcnfArg>)

Function application: f(args...).



Proj(String, u32, LcnfVarId)

Projection: proj_idx(struct_var).



Ctor(String, u32, Vec<LcnfArg>)

Constructor application: Ctor(args...).



Lit(LcnfLit)

Literal value.



Erased

Erased value.



FVar(LcnfVarId)

A free variable reference (unresolved).



Reset(LcnfVarId)

Reset (free fields of) a unique object, returning a reusable memory slot. Used by the reset-reuse optimization to recycle allocations.



Reuse(LcnfVarId, String, u32, Vec<LcnfArg>)

Reuse a freed slot to construct a new value. Reuse(slot, ctor_name, ctor_tag, args) — like Ctor but using pre-allocated memory.