LuaBackend

Struct LuaBackend 

pub struct LuaBackend { /* private fields */ }
Lua code generation backend.

Implementations

Source

impl LuaBackend

pub fn new() -> Self

Create a new LuaBackend.

pub fn fresh_var(&mut self) -> String

Generate a fresh variable name.

pub fn mangle_name(&mut self, name: &str) -> String

Mangle an OxiLean name to a valid Lua identifier.

pub fn lcnf_to_lua_type(ty: &LcnfType) -> LuaType

Map an LCNF type to a Lua type hint.

pub fn compile_lit(lit: &LcnfLit) -> LuaExpr

Compile an LCNF literal to a Lua expression.

pub fn compile_let_value(&mut self, value: &LcnfLetValue) -> LuaExpr

Compile an LCNF literal value to a Lua expression.

pub fn compile_arg(&mut self, arg: &LcnfArg) -> LuaExpr

Compile an LCNF argument to a Lua expression.

pub fn compile_expr( &mut self, expr: &LcnfExpr, stmts: &mut Vec<LuaStmt>, ) -> LuaExpr

Compile an LCNF expression into a list of Lua statements, returning the result expression.

pub fn compile_decl( &mut self, decl: &LcnfFunDecl, ) -> Result<LuaFunction, String>

Compile an LCNF function declaration to a LuaFunction.

pub fn emit_module(&mut self, decls: &[LcnfFunDecl]) -> LuaModule

Compile a list of declarations and emit a LuaModule.