pub fn simplify(expr: AlgExpr, cfg: &AlgSimplConfig) -> SimplResultExpand description
Simplify expr according to cfg, returning a SimplResult with the
simplified expression, a trace of applied rules, and statistics.
pub fn simplify(expr: AlgExpr, cfg: &AlgSimplConfig) -> SimplResultSimplify expr according to cfg, returning a SimplResult with the
simplified expression, a trace of applied rules, and statistics.