AliasResult

Enum AliasResult 

pub enum AliasResult {
    MustAlias,
    MayAlias,
    NoAlias,
}
The result of querying whether two values may alias.

Variants



MustAlias

The two values definitely refer to the same memory location.



MayAlias

The two values may or may not refer to the same location.



NoAlias

The two values definitely do not refer to the same location.

Implementations

Source

impl AliasResult

pub fn may_alias(self) -> bool

Returns true if aliasing is possible (MustAlias or MayAlias).

pub fn must_alias(self) -> bool

Returns true if aliasing is certain.

pub fn no_alias(self) -> bool

Returns true if no alias is possible.

pub fn merge(self, other: AliasResult) -> AliasResult

Merge two alias results conservatively.