pub enum CacheLevel {
L1,
L2,
L3,
Ram,
}Expand description
Represents a level of the memory hierarchy.
Variants
L1
L1 data cache: typically ~32 KB, ~4 cycle latency.
L2
L2 unified cache: typically ~256 KB, ~12 cycle latency.
L3
L3 last-level cache: typically ~8 MB, ~40 cycle latency.
Ram
Main memory (RAM): 100+ cycle latency.
Implementations
Sourceimpl CacheLevel
impl CacheLevel
Sourcepub fn capacity_bytes(&self) -> u64
pub fn capacity_bytes(&self) -> u64
Returns the typical capacity in bytes for this cache level.
Sourcepub fn latency_cycles(&self) -> u32
pub fn latency_cycles(&self) -> u32
Returns the typical access latency in cycles for this cache level.