Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

let_value_to_key
Normalize a let-bound value into an ExprKey, or None if the value is not a candidate for CSE (e.g. impure, reset, reuse).
optimize_cse
Run CSE on a vector of function declarations with default configuration.