Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

AvailableExpr
An expression that is currently available at a program point.
AvailableSet
The set of expressions available at a given program point.
CSEAnalysisCache
CSECacheEntry
CSEConstantFoldingHelper
CSEDepGraph
CSEDominatorTree
CSEExtCache
Analysis cache for CSEExt.
CSEExtConstFolder
Constant folding helper for CSEExt.
CSEExtDepGraph
Dependency graph for CSEExt.
CSEExtDomTree
Dominator tree for CSEExt.
CSEExtLiveness
Liveness analysis for CSEExt.
CSEExtPassConfig
Configuration for CSEExt passes.
CSEExtPassRegistry
Pass registry for CSEExt.
CSEExtPassStats
Statistics for CSEExt passes.
CSEExtWorklist
Worklist for CSEExt.
CSELivenessInfo
CSEPass
Common Subexpression Elimination pass.
CSEPassConfig
CSEPassRegistry
CSEPassStats
CSEWorklist
CSEX2Cache
Analysis cache for CSEX2.
CSEX2ConstFolder
Constant folding helper for CSEX2.
CSEX2DepGraph
Dependency graph for CSEX2.
CSEX2DomTree
Dominator tree for CSEX2.
CSEX2Liveness
Liveness analysis for CSEX2.
CSEX2PassConfig
Configuration for CSEX2 passes.
CSEX2PassRegistry
Pass registry for CSEX2.
CSEX2PassStats
Statistics for CSEX2 passes.
CSEX2Worklist
Worklist for CSEX2.
CseConfig
Configuration for the CSE pass.
CseReport
Summary statistics produced by the CSE pass.
DominatorTree
Simplified dominator information for CSE.
GvnTable
Global Value Numbering (GVN) table.

Enums

CSEExtPassPhase
Pass execution phase for CSEExt.
CSEPassPhase
CSEX2PassPhase
Pass execution phase for CSEX2.
ExprKey
A canonical, hashable key derived from an LCNF let-bound value.