pub struct LiveVariableInfo {
pub live_after: HashMap<LcnfVarId, HashSet<LcnfVarId>>,
pub live_at_entry: HashSet<LcnfVarId>,
}Expand description
Liveness information: the set of variables live at each let-binding site (identified by the variable introduced at that site).
A variable x is live at a program point if there exists a path from
that point to a use of x that doesn’t first re-define x.
Fields
live_after: HashMap<LcnfVarId, HashSet<LcnfVarId>>live_after[x] = set of variables live after the binding of x.
live_at_entry: HashSet<LcnfVarId>Variables live at the entry of the function.
Implementations