pub struct DomTreeNode {
pub var: LcnfVarId,
pub children: Vec<LcnfVarId>,
pub depth: u32,
}Expand description
A node in the dominator tree of the LCNF expression structure.
In ANF/LCNF, the dominator tree mirrors the nesting of let expressions:
the binding of x dominates everything in the body of the let.
Fields
var: LcnfVarIdThe variable introduced at this node.
children: Vec<LcnfVarId>Children in the dominator tree (variables dominated by this node).
depth: u32Depth in the dominator tree (root = 0).