LeaderFinder

Struct LeaderFinder 

pub struct LeaderFinder { /* private fields */ }
Finds the leader of an equivalence class — the canonical variable that dominates all other members of the class.

In LCNF, dominance is determined by binding order (earlier binding dominates later bindings in the same scope).

Implementations

Source

impl LeaderFinder

pub fn new() -> Self

pub fn record(&mut self, vn: ValueNumber, var: LcnfVarId)

Record that var belongs to equivalence class vn.

pub fn leader(&self, vn: ValueNumber) -> Option<LcnfVarId>

Return the leader of the equivalence class for vn.

pub fn members(&self, vn: ValueNumber) -> &[LcnfVarId]

Return all members of the equivalence class for vn.

pub fn num_redundancies(&self) -> usize

Return the number of non-singleton equivalence classes.