Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

collect_callees
Collect all function names called in an expression.
estimate_size
Estimate the “size” of a function declaration in abstract units.
run_inline_pass
Run the inlining pass with default configuration and return a report.
run_inline_pass_with_config
Run the inlining pass with custom configuration and return a report.