pub fn run_inline_pass(decls: &mut [LcnfFunDecl]) -> InlineReportExpand description
Run the inlining pass with default configuration and return a report.
pub fn run_inline_pass(decls: &mut [LcnfFunDecl]) -> InlineReportRun the inlining pass with default configuration and return a report.