pub struct InlineContextStack { /* private fields */ }Expand description
Context-sensitive inline stack, used to detect context-specific inlining opportunities (e.g., inlining differently depending on call chain).
Implementations
Sourceimpl InlineContextStack
impl InlineContextStack
Sourcepub fn pop(&mut self) -> Option<InlineContextFrame>
pub fn pop(&mut self) -> Option<InlineContextFrame>
Pop the most recent frame.
Sourcepub fn contains(&self, callee: &str) -> bool
pub fn contains(&self, callee: &str) -> bool
Returns true if callee appears anywhere in the current context.
Sourcepub fn fingerprint(&self) -> String
pub fn fingerprint(&self) -> String
Returns the context fingerprint as a concatenation of callee names.