InlineHeuristics

Struct InlineHeuristics 

pub struct InlineHeuristics {
    pub max_inline_size: u64,
    pub max_inline_depth: u32,
    pub always_inline_threshold: u64,
    pub never_inline_size: u64,
}
Tunable parameters that govern inlining decisions.

Fields

max_inline_size: u64

Maximum body size (in abstract units) that will be inlined unconditionally.

max_inline_depth: u32

Maximum call-stack depth at which inlining is still allowed.

always_inline_threshold: u64

Functions called at least this many times are considered “always inline”.

never_inline_size: u64

Functions larger than this are never inlined regardless of other factors.

Implementations

Source

impl InlineHeuristics

pub fn new() -> Self

Construct default heuristics.

pub fn decide( &self, decl: &LcnfFunDecl, profile: &InlineProfile, ) -> InlineDecision

Decide how to inline decl given profile.