pub struct InterproceduralInlinePass {
pub config: InlineConfig,
pub budget: InlineBudget,
pub history: InlineHistory,
pub trace: InlineTrace,
pub stats: ExtendedInlineStats,
pub context_stack: InlineContextStack,
}Expand description
Full interprocedural inlining pass that combines:
- Call graph construction
- SCC-based inlining order
- Budget enforcement
- Hot-path detection
- History tracking to prevent redundant inlining
Fields
config: InlineConfigbudget: InlineBudgethistory: InlineHistorytrace: InlineTracestats: ExtendedInlineStatscontext_stack: InlineContextStackImplementations
Sourceimpl InterproceduralInlinePass
impl InterproceduralInlinePass
Sourcepub fn new(config: InlineConfig) -> Self
pub fn new(config: InlineConfig) -> Self
Create a new interprocedural inline pass with the given config.
Sourcepub fn run(&mut self, decls: &mut Vec<LcnfFunDecl>)
pub fn run(&mut self, decls: &mut Vec<LcnfFunDecl>)
Run the pass over a set of function declarations.