pub fn create_preheader(cfg: &mut LicmCfg, loop_: &mut LoopInfo)Expand description
Create a preheader block for loop_ and insert it into cfg.
The preheader is a new block that becomes the sole predecessor of the loop header from outside the loop. All non-back-edge predecessors of the header are redirected to the preheader.