recognize_invariant_pattern

Function recognize_invariant_pattern 

pub fn recognize_invariant_pattern(
    val: &LcnfLetValue,
    body_vars: &HashSet<LcnfVarId>,
) -> Option<InvariantPattern>
Try to recognize the invariant pattern of a LcnfLetValue, given the set of variables defined inside the loop.