pub struct HoistCandidate {
pub expr: LoopInvariantExpr,
pub target_loop_header: LcnfVarId,
pub savings_estimate: u32,
}Expand description
A candidate expression ready to be hoisted to a preheader.
Fields
expr: LoopInvariantExprThe invariant binding to hoist.
target_loop_header: LcnfVarIdThe id of the loop this candidate should be hoisted out of.
savings_estimate: u32Estimated number of redundant evaluations saved (loop trip count heuristic; we use 10 as a conservative default).