pub struct LoopInfo {
pub header: usize,
pub body: Vec<usize>,
pub preheader: Option<usize>,
pub back_edges: Vec<(usize, usize)>,
}Expand description
Information about a natural loop identified in a CFG.
Fields
header: usizeBlock index of the loop header (dominator of all blocks in the loop).
body: Vec<usize>All block indices that make up the loop body (including the header).
preheader: Option<usize>Optional preheader block index inserted before the loop header.
back_edges: Vec<(usize, usize)>Back-edges (from, to) where to is the header.