pub struct LoopNestInfo {
pub max_depth: u32,
pub total_body_vars: usize,
pub loops: Vec<LoopStructure>,
}Expand description
Loop nest information aggregated from a set of loop structures.
Fields
max_depth: u32Maximum nesting depth among all loops.
total_body_vars: usizeTotal number of body variables across all loops.
loops: Vec<LoopStructure>The loop structures.
Implementations
Sourceimpl LoopNestInfo
impl LoopNestInfo
Sourcepub fn from_loops(loops: Vec<LoopStructure>) -> Self
pub fn from_loops(loops: Vec<LoopStructure>) -> Self
Build loop nest info from a vector of loop structures.