Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Traits

LoopOptPass
Trait for a single loop optimization pass in the pipeline.

Functions

count_var_refs
Count the number of distinct variable references in an expression.
estimate_expr_size
Estimate the abstract instruction count of an LCNF expression.