DominanceFrontier

Struct DominanceFrontier 

pub struct DominanceFrontier {
    pub join_vars: HashSet<LcnfVarId>,
}
A “dominance frontier” in the LCNF tree sense.

In LCNF, the IR is tree-structured. A variable x defined in an ancestor let-binding dominates all uses below it. A dominance frontier arises only at Case merge points, where different branches may define different values for a variable.

We represent the frontier simply as the set of LcnfVarIds that are defined in at least one branch of a case expression but used after the case expression (i.e., in code that post-dominates the case).

Fields

join_vars: HashSet<LcnfVarId>

Variables that are live across at least one case-branch boundary.