ParallelPass

Struct ParallelPass 

pub struct ParallelPass {
    pub config: ParallelConfig,
    pub regions: Vec<ParallelRegion>,
    /* private fields */
}
The main parallelism optimisation pass.

Fields

config: ParallelConfig

Configuration.

regions: Vec<ParallelRegion>

Regions identified during analysis.

Implementations

Source

impl ParallelPass

pub fn new(config: ParallelConfig) -> Self

Create a new pass with the given configuration.

pub fn default_pass() -> Self

Create a pass with default configuration.

pub fn run(&mut self, decls: &mut [LcnfFunDecl])

Run analysis + transformation over all function declarations.

pub fn analyze_parallelism(&mut self, decls: &[LcnfFunDecl])

Analyse all declarations and populate self.regions.

pub fn transform_to_parallel(&mut self, decls: &mut [LcnfFunDecl])

Transform declarations that have profitable parallel regions.

Currently adds an annotation to the function body (via LcnfExpr::Let with a sentinel Ctor value) so that downstream code generators can see the annotation. A full production implementation would rewrite the loop body to use a parallel runtime API.

pub fn report(&self) -> ParallelReport

Produce a summary report of the pass results.