Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

decompose_mul
Decompose c into a sum of signed powers-of-two within budget terms.
is_power_of_two
Return true iff n is a power of two (and > 0).
log2
Integer log2 for a power-of-two value.
optimize_strength
Run strength reduction on a vector of declarations with default config.