ObjectLayout

Struct ObjectLayout 

pub struct ObjectLayout {
    pub tag_bits: u8,
    pub rc_offset: usize,
    pub payload_offset: usize,
    pub total_size: usize,
    pub alignment: usize,
    pub num_obj_fields: usize,
    pub scalar_size: usize,
    pub tag: ObjectTag,
}
Memory layout of a runtime object.

All OxiLean heap objects share a common header layout:

+--------+---------+---------+----------+
| RC (8) | Tag (1) | Other   | Padding  |
+--------+---------+---------+----------+
| Payload ...                            |
+----------------------------------------+

Fields

tag_bits: u8

Number of bits used for the object tag in the header.

rc_offset: usize

Byte offset of the reference count field from object start.

payload_offset: usize

Byte offset of the payload from object start.

total_size: usize

Total size of the object in bytes (header + payload).

alignment: usize

Required alignment in bytes.

num_obj_fields: usize

Number of object (pointer) fields in the payload.

scalar_size: usize

Size of scalar (non-pointer) data in bytes.

tag: ObjectTag

The object tag.

Implementations

Source

impl ObjectLayout

pub const HEADER_SIZE: usize = 16

Size of the standard object header.

pub const RC_OFFSET: usize = 0

Offset of the reference count within the header.

pub const TAG_OFFSET: usize = 8

Offset of the tag within the header.

pub const DEFAULT_ALIGN: usize = 8

Default alignment.

pub fn for_ctor( _ctor_tag: u32, num_obj_fields: usize, scalar_size: usize, ) -> Self

Create a layout for a constructor object with the given fields.

pub fn for_closure(_arity: usize, num_captured: usize) -> Self

Create a layout for a closure object.

pub fn for_array(capacity: usize) -> Self

Create a layout for an array object.

pub fn for_external() -> Self

Create a layout for an external object.

pub fn obj_field_offset(&self, idx: usize) -> usize

Byte offset of the i-th object field.

pub fn scalar_offset(&self) -> usize

Byte offset of the scalar region.