SolidityType

Enum SolidityType 

pub enum SolidityType {
Show 23 variants Uint256, Uint128, Uint64, Uint32, Uint8, Int256, Int128, Int64, Int32, Int8, Address, AddressPayable, Bool, Bytes, Bytes32, Bytes16, Bytes4, StringTy, Mapping(Box<SolidityType>, Box<SolidityType>), DynArray(Box<SolidityType>), FixedArray(Box<SolidityType>, usize), Named(String), Tuple(Vec<SolidityType>),
}
Solidity ABI type representation.

Variants



Uint256

uint256



Uint128

uint128



Uint64

uint64



Uint32

uint32



Uint8

uint8



Int256

int256



Int128

int128



Int64

int64



Int32

int32



Int8

int8



Address

address



AddressPayable

address payable



Bool

bool



Bytes

bytes



Bytes32

bytes32



Bytes16

bytes16



Bytes4

bytes4



StringTy

string



Mapping(Box<SolidityType>, Box<SolidityType>)

mapping(K => V)



DynArray(Box<SolidityType>)

T[] — dynamic array



FixedArray(Box<SolidityType>, usize)

T[N] — fixed-size array



Named(String)

A named struct or enum type



Tuple(Vec<SolidityType>)

tuple(T0, T1, ...) — used for ABI encoding

Implementations

Source

impl SolidityType

pub fn is_reference_type(&self) -> bool

Returns true if this type is a reference type (stored in memory/storage).

pub fn default_param_location(&self) -> &'static str

Returns the default data location for function parameters of this type.

pub fn abi_canonical(&self) -> String

Returns the ABI-canonical type string (for selector computation).