Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Constants

OXILEAN_SWIFT_RUNTIME
A minimal Swift runtime preamble embedded in every generated module.

Functions

is_swift_keyword
Return true if name is a Swift reserved keyword.