WGSLBuiltinFunction

Enum WGSLBuiltinFunction 

pub enum WGSLBuiltinFunction {
Show 105 variants Abs, Acos, Acosh, Asin, Asinh, Atan, Atanh, Atan2, Ceil, Clamp, Cos, Cosh, Cross, Degrees, Distance, Dot, Exp, Exp2, FaceForward, Floor, Fma, Fract, Frexp, InverseSqrt, Ldexp, Length, Log, Log2, Max, Min, Mix, Modf, Normalize, Pow, Quantize, Radians, Reflect, Refract, Round, Saturate, Sign, Sin, Sinh, Smoothstep, Sqrt, Step, Tan, Tanh, Transpose, Trunc, CountLeadingZeros, CountOneBits, CountTrailingZeros, ExtractBits, FirstLeadingBit, FirstTrailingBit, InsertBits, ReverseBits, TextureDimensions, TextureGather, TextureGatherCompare, TextureLoad, TextureNumLayers, TextureNumLevels, TextureNumSamples, TextureSample, TextureSampleBias, TextureSampleCompare, TextureSampleCompareLevel, TextureSampleGrad, TextureSampleLevel, TextureStore, Dpdx, Dpdxcoarse, Dpdxfine, Dpdy, Dpdycoarse, Dpdyfine, Fwidth, FwidthCoarse, FwidthFine, AtomicLoad, AtomicStore, AtomicAdd, AtomicSub, AtomicMax, AtomicMin, AtomicAnd, AtomicOr, AtomicXor, AtomicExchange, AtomicCompareExchangeWeak, WorkgroupBarrier, StorageBarrier, TextureBarrier, Pack2x16float, Pack2x16snorm, Pack2x16unorm, Pack4x8snorm, Pack4x8unorm, Unpack2x16float, Unpack2x16snorm, Unpack2x16unorm, Unpack4x8snorm, Unpack4x8unorm,
}
Standard WGSL built-in functions for code generation helpers.

Variants



Abs



Acos



Acosh



Asin



Asinh



Atan



Atanh



Atan2



Ceil



Clamp



Cos



Cosh



Cross



Degrees



Distance



Dot



Exp



Exp2



FaceForward



Floor



Fma



Fract



Frexp



InverseSqrt



Ldexp



Length



Log



Log2



Max



Min



Mix



Modf



Normalize



Pow



Quantize



Radians



Reflect



Refract



Round



Saturate



Sign



Sin



Sinh



Smoothstep



Sqrt



Step



Tan



Tanh



Transpose



Trunc



CountLeadingZeros



CountOneBits



CountTrailingZeros



ExtractBits



FirstLeadingBit



FirstTrailingBit



InsertBits



ReverseBits



TextureDimensions



TextureGather



TextureGatherCompare



TextureLoad



TextureNumLayers



TextureNumLevels



TextureNumSamples



TextureSample



TextureSampleBias



TextureSampleCompare



TextureSampleCompareLevel



TextureSampleGrad



TextureSampleLevel



TextureStore



Dpdx



Dpdxcoarse



Dpdxfine



Dpdy



Dpdycoarse



Dpdyfine



Fwidth



FwidthCoarse



FwidthFine



AtomicLoad



AtomicStore



AtomicAdd



AtomicSub



AtomicMax



AtomicMin



AtomicAnd



AtomicOr



AtomicXor



AtomicExchange



AtomicCompareExchangeWeak



WorkgroupBarrier



StorageBarrier



TextureBarrier



Pack2x16float



Pack2x16snorm



Pack2x16unorm



Pack4x8snorm



Pack4x8unorm



Unpack2x16float



Unpack2x16snorm



Unpack2x16unorm



Unpack4x8snorm



Unpack4x8unorm

Implementations

Source

impl WGSLBuiltinFunction

pub fn name(&self) -> &'static str

Return the WGSL name of this built-in function.

pub fn call(&self, args: &[&str]) -> String

Generate a WGSL call expression string for this built-in.