ZigBackend

Struct ZigBackend 

pub struct ZigBackend;
The Zig code generation backend.

Implementations

Source

impl ZigBackend

pub fn new() -> Self

Create a new ZigBackend.

pub fn emit_module(&self, module: &ZigModule) -> String

Emit source code for a complete Zig module.

pub fn emit_fn(&self, f: &ZigFn) -> String

Emit source code for a single Zig function.

pub fn emit_struct(&self, s: &ZigStruct) -> String

Emit source code for a single Zig struct.

pub fn compile_name(oxilean_name: &str) -> String

Sanitize an OxiLean name for use as a Zig identifier.

Replaces dots and other special characters with underscores, prepends ox_ if the name starts with a digit or is a Zig keyword.