BeamType

Enum BeamType 

pub enum BeamType {
Show 15 variants Integer, Float, Atom, Pid, Port, Reference, Binary, List(Box<BeamType>), Tuple(Vec<BeamType>), Map(Box<BeamType>, Box<BeamType>), Fun(Vec<BeamType>, Box<BeamType>), Any, None, Union(Vec<BeamType>), Named(String),
}
BEAM VM type representation.

BEAM is dynamically typed; these types are used for documentation and static analysis purposes within the code generator.

Variants



Integer

Fixed-precision integer (maps to Erlang integer())



Float

Floating-point number (maps to Erlang float())



Atom

Atom (interned symbol, maps to Erlang atom())



Pid

Process identifier (maps to Erlang pid())



Port

Port identifier (maps to Erlang port())



Reference

Unique reference (maps to Erlang reference())



Binary

Binary data (maps to Erlang binary())



List(Box<BeamType>)

Linked list (maps to Erlang list())



Tuple(Vec<BeamType>)

Heterogeneous tuple (maps to Erlang tuple())



Map(Box<BeamType>, Box<BeamType>)

Key-value map (maps to Erlang map())



Fun(Vec<BeamType>, Box<BeamType>)

First-class function value (maps to Erlang fun())



Any

Any type (Erlang any())



None

No return type (Erlang none())



Union(Vec<BeamType>)

Union of types



Named(String)

Named type alias or user-defined type