IrDeserializeResult

Enum IrDeserializeResult 

pub enum IrDeserializeResult {
    Ok(SerializedIr),
    VersionMismatch {
        expected: u32,
        found: u32,
    },
    ParseError(String),
    Unsupported(String),
}
The result of attempting to deserialize an IR snapshot.

Variants



Ok(SerializedIr)

Deserialization succeeded.



VersionMismatch

The snapshot was written with a different format version.

Fields

expected: u32

The version the deserializer expects.

found: u32

The version found in the data.



ParseError(String)

The input could not be parsed.



Unsupported(String)

The requested format is not supported by this deserializer.