pub enum AliasResult {
MustAlias,
MayAlias,
NoAlias,
}Expand description
The result of querying whether two values may alias.
Variants
MustAlias
The two values definitely refer to the same memory location.
MayAlias
The two values may or may not refer to the same location.
NoAlias
The two values definitely do not refer to the same location.
Implementations
Sourceimpl AliasResult
impl AliasResult
Sourcepub fn must_alias(self) -> bool
pub fn must_alias(self) -> bool
Returns true if aliasing is certain.
Sourcepub fn merge(self, other: AliasResult) -> AliasResult
pub fn merge(self, other: AliasResult) -> AliasResult
Merge two alias results conservatively.