pub enum EscapeStatus {
NoEscape,
LocalEscape,
HeapEscape,
ReturnEscape,
ArgumentEscape(usize),
Unknown,
}Expand description
The escape status of an allocation site.
Variants
NoEscape
The allocation does not escape: safe for stack allocation.
LocalEscape
The allocation escapes to a local variable only.
HeapEscape
The allocation escapes to the heap (assigned to a heap-allocated struct).
ReturnEscape
The allocation is returned from the function.
ArgumentEscape(usize)
The allocation escapes as argument index usize of some call.
Unknown
Escape status is unknown (conservative assumption).
Implementations
Sourceimpl EscapeStatus
impl EscapeStatus
Sourcepub fn is_heap_allocated(&self) -> bool
pub fn is_heap_allocated(&self) -> bool
Returns true if this allocation must live on the heap.
Sourcepub fn can_stack_allocate(&self) -> bool
pub fn can_stack_allocate(&self) -> bool
Returns true if this allocation can be placed on the stack.