Auto-generated module
🤖 Generated with SplitRS
Functions
- collect_
callees - Collect all function names called in an expression.
- estimate_
size - Estimate the “size” of a function declaration in abstract units.
- run_
inline_ pass - Run the inlining pass with default configuration and return a report.
- run_
inline_ pass_ with_ config - Run the inlining pass with custom configuration and return a report.