ClosureLayout

Struct ClosureLayout 

pub struct ClosureLayout {
    pub fn_ptr_offset: usize,
    pub env_offset: usize,
    pub env_size: usize,
    pub arity: usize,
    pub num_captured: usize,
    pub object_layout: ObjectLayout,
}
Detailed layout information for a closure.

Fields

fn_ptr_offset: usize

Byte offset of the function pointer from closure start.

env_offset: usize

Byte offset of the captured environment from closure start.

env_size: usize

Total size of the captured environment in bytes.

arity: usize

Number of parameters the function takes (total arity).

num_captured: usize

Number of captured variables.

object_layout: ObjectLayout

The overall object layout.

Implementations

Source

impl ClosureLayout

pub fn new(arity: usize, num_captured: usize) -> Self

Create a closure layout for a function with the given arity and captured variable count.

pub fn captured_var_offset(&self, idx: usize) -> usize

Byte offset of the i-th captured variable.