pub struct WGSLTypeChecker;Expand description
Lightweight WGSL type checker.
Implementations
Sourceimpl WGSLTypeChecker
impl WGSLTypeChecker
Sourcepub fn check_binop(
&self,
_op: &str,
lhs: &WGSLType,
rhs: &WGSLType,
) -> Result<WGSLType, WGSLTypeError>
pub fn check_binop( &self, _op: &str, lhs: &WGSLType, rhs: &WGSLType, ) -> Result<WGSLType, WGSLTypeError>
Check that two types match for a binary arithmetic operation.
Sourcepub fn check_atomic(&self, ty: &WGSLType) -> Result<(), WGSLTypeError>
pub fn check_atomic(&self, ty: &WGSLType) -> Result<(), WGSLTypeError>
Check that a type is valid for atomic operations.
Check that a type is host-shareable (can be used in uniform/storage buffers).
Sourcepub fn element_type(ty: &WGSLType) -> &WGSLType
pub fn element_type(ty: &WGSLType) -> &WGSLType
Return the component type of a vector, or the type itself if scalar.
Sourcepub fn vector_width(ty: &WGSLType) -> u32
pub fn vector_width(ty: &WGSLType) -> u32
Return the number of vector components, or 1 for scalars.